# Search for xcms on bioconductor
source("http://bioconductor.org/biocLite.R")
biocLite("xcms", "faahKO")
biocLite("pcaMethods")
biocLite("MASS")

# load from library
library(xcms)
library(faahKO)
library(pcaMethods)

cdfpath <- system.file("cdf", package = "faahKO")
cdffiles <- list.files(cdfpath, recursive = TRUE,full=T)
xset <- xcmsSet(cdffiles)
xsg <- group(xset)
xsg <- retcor(xsg)
xsg <- group(xsg,bw=10)
xsg <- fillPeaks(xsg)

## Get peak intensity values
values <- groupval(xsg, value="into")

## Numerical matrix with with samples in rows and variables as columns
data <- t(values) #transpose data

## Normalize each mass signal to max=1
for (r in 1:ncol(data))
    data[,r] <- data[,r] / max(data[,r])


##  PCA Example
pca.result <- pca(data, nPcs = 3, scale="none", cv="q2")

## Get the estimated principal axes (loadings)
loadings <- pca.result@loadings

## Get the estimated scores
scores <- pca.result@scores

## Now plot the scores
plotPcs(pca.result, type = "scores",col=as.integer(sampclass(xsg)) + 1)

## look to see if the model is valid
plot(pca.result)
pca.result

## MDS Example
library(MASS)

## MDS
data.dist <- dist(data)
mds <- isoMDS(data.dist)
plot(mds$points, type = "n")
text(mds$points, labels = rownames(data),col=as.integer(sampclass(xsg)) + 1)

