#Heirachical Clustering
#http://msbi.ipb-halle.de/~sneumann/05-clusterrep.R

setwd("C:/Users/schymaem/Documents/EDA_EMERGE/October2012Workshop")
library(rcdk)

## https://github.com/rajarshi/cdkr/blob/master/data/BL.sdf
mols <- load.molecules("BL.sdf")

get.fingerprint(mols[[1]], type="extended")
## Create fingerprints
fps <- lapply(mols, get.fingerprint, type = "extended")

## Calculate Distance Matrix
fp.sim <- fp.sim.matrix(fps, method = "tanimoto")
fp.dist <- 1 - fp.sim

## Cluster and Plot
cluster <- hclust(as.dist(fp.dist))

## Create actual cluster associations
classlabel <- as.factor(cutree(cluster, h=0.2))
table(classlabel)

## Plot and print molecules
plot(cluster)
identify(cluster, function(k) view.molecule.2d(mols[k]))

## Function to create Maximum Common Substructure
mcss <- function(x) {
  l <- length(x)
  
  if (l==1)
    return (x[[1]])
  
  consensus <- x[[1]]  
  for (i in 2:l) {
    consensus <- get.mcs(consensus, x[[i]])
  }
  return (consensus)  
}

## Plot and print MCSS
plot(cluster)
# this is really, really slow
identify(cluster, function(k) view.molecule.2d(mcss(mols[k])))


##
## View the cluster representative and the individual members.
## Beware: may create many plots !
##
clusterreps <- tapply(mols, classlabel, mcss)

mapply(function(consensus, molecules) {view.molecule.2d(c(list(consensus),
                                                          unlist(molecules)))},
       clusterreps, tapply(mols, classlabel, list))


